<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pt">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="20"/>
        <location filename="../mainwindow.cpp" line="131"/>
        <source>MX Package Installer</source>
        <translation>MX Instalador de Pacotes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="57"/>
        <source>Popular Applications</source>
        <translation>Aplicações seleccionadas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="73"/>
        <source>Category</source>
        <translation>Categoria</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="83"/>
        <source>Package</source>
        <translation>Pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="88"/>
        <source>Info</source>
        <translation>Informação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="93"/>
        <location filename="../mainwindow.ui" line="420"/>
        <location filename="../mainwindow.ui" line="817"/>
        <location filename="../mainwindow.ui" line="1074"/>
        <source>Description</source>
        <translation>Descrição</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="101"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Manage popular packages&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;&lt;span style=&quot; font-size:16pt;&quot;&gt;Instalar/Desinstalar pacotes colectados pela equipa do MX&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="120"/>
        <location filename="../mainwindow.ui" line="190"/>
        <location filename="../mainwindow.ui" line="686"/>
        <location filename="../mainwindow.ui" line="1099"/>
        <location filename="../mainwindow.ui" line="1208"/>
        <source>search</source>
        <translation>procurar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="149"/>
        <location filename="../mainwindow.ui" line="203"/>
        <location filename="../mainwindow.ui" line="699"/>
        <location filename="../mainwindow.ui" line="1167"/>
        <location filename="../mainwindow.ui" line="1431"/>
        <source>= Installed packages</source>
        <translation>= Pacotes instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="172"/>
        <source>Enabled Repos</source>
        <translation>Dos repositórios activos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="230"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remove all the packages that are marked as &amp;quot;autoremovable&amp;quot;. If you want to manage them, select Autoremovable from drop-down selection box.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Remover todos os pacotes que estão marcados como &amp;quot;autoremovable&amp;quot;. Se desejar geri-los, escolha Autoremovível na caixa de seleção.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="233"/>
        <source>Autoremove packages</source>
        <translation>Remover pacotes automaticamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="341"/>
        <location filename="../mainwindow.ui" line="1324"/>
        <source>Upgrade All</source>
        <translation>Atualizar todos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="284"/>
        <location filename="../mainwindow.ui" line="547"/>
        <location filename="../mainwindow.ui" line="926"/>
        <source>Installed:</source>
        <translation>Instalados:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="368"/>
        <location filename="../mainwindow.ui" line="540"/>
        <location filename="../mainwindow.ui" line="947"/>
        <source>Total packages:</source>
        <translation>Total de pacotes:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="354"/>
        <location filename="../mainwindow.ui" line="662"/>
        <location filename="../mainwindow.ui" line="987"/>
        <source>Also Install &quot;Recommended&quot; Packages</source>
        <translation>Instalar também pacotes &quot;Recomendados&quot;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="314"/>
        <location filename="../mainwindow.ui" line="577"/>
        <location filename="../mainwindow.ui" line="919"/>
        <source>Upgradable:</source>
        <translation>Atualizáveis:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="243"/>
        <location filename="../mainwindow.ui" line="584"/>
        <location filename="../mainwindow.ui" line="954"/>
        <source>Hide library and developer packages</source>
        <translation>Ocultar pacotes de bibliotecas e de programador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="265"/>
        <location filename="../mainwindow.ui" line="633"/>
        <location filename="../mainwindow.ui" line="1006"/>
        <location filename="../mainwindow.ui" line="1524"/>
        <source>Refresh list</source>
        <translation>Recarregar a lista</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="481"/>
        <location filename="../mainwindow.ui" line="758"/>
        <location filename="../mainwindow.ui" line="1129"/>
        <location filename="../mainwindow.ui" line="1479"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filter packages according to their status.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Filtrar pacotes pelo estado.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="484"/>
        <location filename="../mainwindow.ui" line="488"/>
        <location filename="../mainwindow.ui" line="761"/>
        <location filename="../mainwindow.ui" line="765"/>
        <location filename="../mainwindow.ui" line="1132"/>
        <location filename="../mainwindow.ui" line="1136"/>
        <location filename="../mainwindow.cpp" line="3054"/>
        <source>All packages</source>
        <translation>Todos os pacotes</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="493"/>
        <location filename="../mainwindow.ui" line="770"/>
        <location filename="../mainwindow.ui" line="1141"/>
        <location filename="../mainwindow.cpp" line="3074"/>
        <source>Installed</source>
        <translation>Instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="498"/>
        <location filename="../mainwindow.ui" line="775"/>
        <location filename="../mainwindow.ui" line="1146"/>
        <location filename="../mainwindow.cpp" line="3075"/>
        <source>Upgradable</source>
        <translation>Atualizáveis</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="503"/>
        <location filename="../mainwindow.ui" line="780"/>
        <location filename="../mainwindow.ui" line="1151"/>
        <location filename="../mainwindow.ui" line="1516"/>
        <location filename="../mainwindow.cpp" line="3039"/>
        <location filename="../mainwindow.cpp" line="3076"/>
        <location filename="../mainwindow.cpp" line="3178"/>
        <location filename="../mainwindow.cpp" line="3179"/>
        <source>Not installed</source>
        <translation>Não instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="508"/>
        <location filename="../mainwindow.ui" line="785"/>
        <location filename="../mainwindow.ui" line="1156"/>
        <location filename="../mainwindow.cpp" line="2574"/>
        <location filename="../mainwindow.cpp" line="3010"/>
        <location filename="../mainwindow.cpp" line="3077"/>
        <location filename="../mainwindow.cpp" line="3163"/>
        <source>Autoremovable</source>
        <translation>Autoremovível</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="450"/>
        <location filename="../mainwindow.ui" line="727"/>
        <location filename="../mainwindow.ui" line="855"/>
        <source>= Upgradable package. Newer version available in selected repository.</source>
        <translation>= Pacote instalado. Versão mais recente disponível noutro repositório.</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="405"/>
        <location filename="../mainwindow.ui" line="802"/>
        <location filename="../mainwindow.ui" line="1059"/>
        <source>Package Name</source>
        <translation>Nome do pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1259"/>
        <source>Version</source>
        <translation>Versão</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="523"/>
        <source>MX Test Repo</source>
        <translation>MX Test</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="410"/>
        <location filename="../mainwindow.ui" line="807"/>
        <location filename="../mainwindow.ui" line="1064"/>
        <source>Repo Version</source>
        <translation>Versão do repositório</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="415"/>
        <location filename="../mainwindow.ui" line="812"/>
        <location filename="../mainwindow.ui" line="1069"/>
        <source>Installed Version</source>
        <translation>Versão instalada</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="837"/>
        <source>Debian Backports</source>
        <translation>Debian Retroportados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1190"/>
        <source>Flatpaks</source>
        <translation>Pacotes flatpak</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1447"/>
        <location filename="../mainwindow.ui" line="1451"/>
        <location filename="../mainwindow.cpp" line="115"/>
        <location filename="../mainwindow.cpp" line="116"/>
        <source>For all users</source>
        <translation>Para todos os utilizadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1456"/>
        <source>For current user</source>
        <translation>Para o presente utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1541"/>
        <source>Remote (repo):</source>
        <translation>Remoto (repositório):</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1482"/>
        <location filename="../mainwindow.ui" line="1486"/>
        <location filename="../mainwindow.cpp" line="3021"/>
        <source>All apps</source>
        <translation>Aplicações</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1491"/>
        <location filename="../mainwindow.cpp" line="3027"/>
        <source>All runtimes</source>
        <translation>Software &apos;runtime&apos;</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1496"/>
        <location filename="../mainwindow.cpp" line="3033"/>
        <source>All available</source>
        <translation>Todos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1501"/>
        <location filename="../mainwindow.cpp" line="3018"/>
        <source>Installed apps</source>
        <translation>Aplicações instaladas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1506"/>
        <location filename="../mainwindow.cpp" line="3015"/>
        <source>Installed runtimes</source>
        <translation>Software &apos;runtime&apos; instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1511"/>
        <location filename="../mainwindow.cpp" line="3037"/>
        <location filename="../mainwindow.cpp" line="3171"/>
        <location filename="../mainwindow.cpp" line="3172"/>
        <source>All installed</source>
        <translation>Todos os instalados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1303"/>
        <source>Total items </source>
        <translation>Total de itens </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1317"/>
        <source>Installed apps:</source>
        <translation>Aplicações instaladas:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1369"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1398"/>
        <source>Total installed size:</source>
        <translation>Tamanho total instalado:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1412"/>
        <source>Remove unused runtimes</source>
        <translation>Remover &apos;runtimes&apos; não utilizados</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1249"/>
        <source>Short Name</source>
        <translation>Nome curto</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1254"/>
        <source>Full Package Name</source>
        <translation>Nome completo do pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1264"/>
        <source>Size</source>
        <translation>Tamanho</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1558"/>
        <location filename="../mainwindow.cpp" line="2717"/>
        <location filename="../mainwindow.cpp" line="2935"/>
        <source>Console Output</source>
        <translation>Processamento</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1564"/>
        <source>Enter</source>
        <translation>Introduzir/Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1574"/>
        <source>Respond here, or just press Enter</source>
        <translation>Responder aqui ou premir Introduzir/Enter</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1633"/>
        <location filename="../mainwindow.cpp" line="1249"/>
        <location filename="../mainwindow.cpp" line="3064"/>
        <location filename="../mainwindow.cpp" line="3072"/>
        <location filename="../mainwindow.cpp" line="3162"/>
        <location filename="../mainwindow.cpp" line="3168"/>
        <location filename="../mainwindow.cpp" line="3463"/>
        <source>Install</source>
        <translation>Instalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1639"/>
        <source>Alt+I</source>
        <translation>Alt+I</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1658"/>
        <source>Quit application</source>
        <translation>Sair da aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1661"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1667"/>
        <source>Alt+C</source>
        <translation>Alt+C</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1699"/>
        <source>About this application</source>
        <translation>Sobre esta aplicação</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1702"/>
        <source>About...</source>
        <translation>Sobre...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1708"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1746"/>
        <source>Display help </source>
        <translation>Mostrar ajuda </translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1749"/>
        <source>Help</source>
        <translation>Ajuda</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1755"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1771"/>
        <source>Uninstall</source>
        <translation>Desinstalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="1777"/>
        <source>Alt+U</source>
        <translation>Alt+U</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="186"/>
        <source>Uninstalling packages...</source>
        <translation>A desinstalar pacotes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Running pre-uninstall operations...</source>
        <translation>A executar operações pré-desinstalação...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="211"/>
        <source>Running post-uninstall operations...</source>
        <translation>A executar operações pós-desinstalação...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="228"/>
        <source>Refreshing sources...</source>
        <translation>A actualizar as origens...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="241"/>
        <location filename="../mainwindow.cpp" line="1297"/>
        <location filename="../mainwindow.cpp" line="1432"/>
        <location filename="../mainwindow.cpp" line="1601"/>
        <location filename="../mainwindow.cpp" line="1666"/>
        <location filename="../mainwindow.cpp" line="1981"/>
        <location filename="../mainwindow.cpp" line="2121"/>
        <location filename="../mainwindow.cpp" line="2567"/>
        <location filename="../mainwindow.cpp" line="2586"/>
        <location filename="../mainwindow.cpp" line="2693"/>
        <location filename="../mainwindow.cpp" line="2709"/>
        <location filename="../mainwindow.cpp" line="2805"/>
        <location filename="../mainwindow.cpp" line="2838"/>
        <location filename="../mainwindow.cpp" line="3271"/>
        <location filename="../mainwindow.cpp" line="3347"/>
        <location filename="../mainwindow.cpp" line="3377"/>
        <location filename="../mainwindow.cpp" line="3479"/>
        <location filename="../mainwindow.cpp" line="3519"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>There was a problem updating sources. Some sources may not have provided updates. For more info check: </source>
        <translation>Houve um problema ao actualizar as origens. Algumas origens podem não ter fornecido actualizações. Para mais informação, ver: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="360"/>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>Could not determine Debian version. Please select your version:</source>
        <translation>Não é possível determinar a versão do Debian. Escolha a sua versão:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>Debian Version</source>
        <translation>Versão do Debian</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="693"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="700"/>
        <source>Please wait...</source>
        <translation>Aguardar...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1113"/>
        <source>You are about to use the MX Test repository, whose packages are provided for testing purposes only. It is possible that they might break your system, so it is suggested that you back up your system and install or update only one package at a time. Please provide feedback in the Forum so the package can be evaluated before moving up to Main.</source>
        <translation>Está prestes a ser usado o repositório MX Test, cujos pacotes são disponibilizados sobretudo para serem testados. Há alguma probabilidade de os pacotes deste repositório danificarem o sistema, pelo que é sugerido que seja feita uma cópia de segurança (backup) do sistema e que seja instalado ou actualizado apenas um pacote de cada vez. Solicita-se que os resultados (execução sem problemas ou com problemas e quais) sejam comunicados no fórum (https://forum.mxlinux.org, em &apos;Select language&apos; escolher Portuguese, registar-se se ainda não registado, e ir para a secção Comunidade), para que seja feita uma re-avaliação dos pacotes antes de serem movidos para o repositório estável. </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1122"/>
        <source>You are about to use Debian Backports, which contains packages taken from the next Debian release (called &apos;testing&apos;), adjusted and recompiled for usage on Debian stable. They cannot be tested as extensively as in the stable releases of Debian and MX Linux, and are provided on an as-is basis, with risk of incompatibilities with other components in Debian stable. Use with care!</source>
        <translation>Está prestes a ser usado o repositório Debian Retroportados. Este repositório contém pacotes retirados da versão Debian &apos;testing&apos; (próxima versão oficial do Debian), adaptados e recompilados para uso na actual versão oficial (Debian &apos;stable&apos;) - sendo por isso designados de pacotes retroportados. Estes pacotes não foram tão extensivamente testados como os das versões estáveis do Debian e do MX; por isso, são disponibilizados &apos;como estão&apos;, com o risco de incompatibilidades com outros componentes do Debian &apos;stable&apos;. Usar com cuidado!</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1130"/>
        <source>MX Linux includes this repository of flatpaks for the users&apos; convenience only, and is not responsible for the functionality of the individual flatpaks themselves. For more, consult flatpaks in the Wiki.</source>
        <translation>O MX inclui este repositório de pacotes flatpak apenas para conveniência dos utilizadores, não sendo responsável pelo funcionamento dos próprios pacotes flatpak. Para mais informação (em inglês) consultar &apos;flatpaks&apos; no Wiki.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1138"/>
        <location filename="../mainwindow.cpp" line="3507"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1142"/>
        <source>Do not show this message again</source>
        <translation>Não mostrar esta mensagem novamente</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1246"/>
        <source>Remove</source>
        <translation>Remover</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1262"/>
        <source>The following packages were selected. Click Show Details for list of changes.</source>
        <translation>Foram selecionados os seguintes pacotes. Clique em Mostrar detalhes para obter a lista de alterações.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1298"/>
        <location filename="../mainwindow.cpp" line="1433"/>
        <location filename="../mainwindow.cpp" line="1667"/>
        <source>Internet is not available, won&apos;t be able to download the list of packages</source>
        <translation>Sem ligação à Internet; não é possível descarregar a lista de pacotes</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1301"/>
        <source>Installing packages...</source>
        <translation>A instalar pacotes...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1359"/>
        <source>Post-processing...</source>
        <translation>Pós-processamento...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1391"/>
        <source>Pre-processing for </source>
        <translation>Pré-processando para </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1405"/>
        <source>Installing </source>
        <translation>A instalar </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1412"/>
        <source>Post-processing for </source>
        <translation>Pós-processando para </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1602"/>
        <source>There was an error downloading or writing the file: %1. Please check your internet connection and free space on your drive</source>
        <translation>Ocorreu um erro ao descarregar ou gravar o ficheiro: %1. Verifique a sua ligação de internet e o espaço livre no seu disco</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1675"/>
        <source>Downloading package info...</source>
        <translation>A descarregar informação do pacote...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="1982"/>
        <source>dpkg-query command returned an error. Please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation>O comando ‘dpkg-query’ retornou um erro. Por favor, execute o comando ‘dpkg-query -W’ no terminal e verifique o resultado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2122"/>
        <source>dpkg-query command returned an error, please run &apos;dpkg-query -W&apos; in terminal and check the output.</source>
        <translation>O comando dpkg-query produziu um erro. Execute o comando ‘dpkg-query -W’ no Terminal e verifique o seu resultado.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2243"/>
        <location filename="../mainwindow.cpp" line="2345"/>
        <location filename="../mainwindow.cpp" line="2368"/>
        <source>Package info</source>
        <translation>Informação do pacote</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2260"/>
        <location filename="../mainwindow.cpp" line="3411"/>
        <source>More &amp;info...</source>
        <translation>Mais &amp;informação...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2291"/>
        <source>Packages to be installed: </source>
        <translation>Pacotes a instalar: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2551"/>
        <location filename="../mainwindow.cpp" line="2563"/>
        <location filename="../mainwindow.cpp" line="2583"/>
        <location filename="../mainwindow.cpp" line="2668"/>
        <location filename="../mainwindow.cpp" line="2690"/>
        <location filename="../mainwindow.cpp" line="3268"/>
        <location filename="../mainwindow.cpp" line="3343"/>
        <location filename="../mainwindow.cpp" line="3371"/>
        <location filename="../mainwindow.cpp" line="3475"/>
        <source>Done</source>
        <translation>Concluído</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2551"/>
        <location filename="../mainwindow.cpp" line="2563"/>
        <location filename="../mainwindow.cpp" line="2583"/>
        <location filename="../mainwindow.cpp" line="2668"/>
        <location filename="../mainwindow.cpp" line="2690"/>
        <location filename="../mainwindow.cpp" line="2706"/>
        <location filename="../mainwindow.cpp" line="3268"/>
        <location filename="../mainwindow.cpp" line="3343"/>
        <location filename="../mainwindow.cpp" line="3371"/>
        <location filename="../mainwindow.cpp" line="3475"/>
        <location filename="../mainwindow.cpp" line="3516"/>
        <source>Processing finished successfully.</source>
        <translation>Processamento terminado com êxito.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2568"/>
        <location filename="../mainwindow.cpp" line="2587"/>
        <location filename="../mainwindow.cpp" line="3272"/>
        <location filename="../mainwindow.cpp" line="3348"/>
        <location filename="../mainwindow.cpp" line="3378"/>
        <source>Problem detected while installing, please inspect the console output.</source>
        <translation>Detectado problema ao instalar; ver informação no separador de processamento.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2597"/>
        <source>About %1</source>
        <translation>Sobre o %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2598"/>
        <source>Version: </source>
        <translation>Versão: </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2600"/>
        <source>Package Installer for MX Linux</source>
        <translation>Gestor de Programas/Pacotes do MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2602"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Direitos de autor (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2603"/>
        <source>%1 License</source>
        <translation>Licença do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2615"/>
        <source>%1 Help</source>
        <translation>Ajuda do %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2693"/>
        <source>We encountered a problem uninstalling, please check output</source>
        <translation>Foi encontrado um problema ao desinstalar. Ver no separador de processamento</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2706"/>
        <location filename="../mainwindow.cpp" line="3516"/>
        <source>Success</source>
        <translation>Êxito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2709"/>
        <location filename="../mainwindow.cpp" line="3519"/>
        <source>We encountered a problem uninstalling the program</source>
        <translation>Houve um problema ao desinstalar o programa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2806"/>
        <location filename="../mainwindow.cpp" line="2839"/>
        <source>Could not download the list of packages. Please check your APT sources.</source>
        <translation>Erro ao descarregar lista de pacotes. Verificar as origens APT.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2876"/>
        <location filename="../mainwindow.cpp" line="2918"/>
        <source>Flatpak not installed</source>
        <translation>Pacote flatpak não instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2877"/>
        <source>Flatpak is not currently installed.
OK to go ahead and install it?</source>
        <translation>O pacote flatpak não está instalado.
Continuar e instalar o pacote?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2918"/>
        <source>Flatpak was not installed</source>
        <translation>O pacote flatpak não estava instalado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2939"/>
        <source>Needs re-login</source>
        <translation>É necessário re-entrar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="2940"/>
        <source>You might need to logout/login to see installed items in the menu</source>
        <translation>Poderá ser necessário sair e re-entrar para que os itens fiquem visíveis no menu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3064"/>
        <location filename="../mainwindow.cpp" line="3072"/>
        <location filename="../mainwindow.cpp" line="3164"/>
        <source>Mark keep</source>
        <translation>Marcar para manter</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3162"/>
        <source>Upgrade</source>
        <translation>Actualizar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3300"/>
        <source>Quit?</source>
        <translation>Sair?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3301"/>
        <source>Process still running, quitting might leave the system in an unstable state.&lt;p&gt;&lt;b&gt;Are you sure you want to exit MX Package Installer?&lt;/b&gt;</source>
        <translation>Processo ainda em execução. Sair pode deixar o sistema num estado instável.&lt;p&gt;&lt;b&gt;Sair realmente do MX Instalador de Pacotes?&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3463"/>
        <source>Reinstall</source>
        <translation>Reinstalar</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3480"/>
        <source>Problem detected during last operation, please inspect the console output.</source>
        <translation>Problema detectado durante a última operação. Consultar o processamento no terminal/consola.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="3508"/>
        <source>Potentially dangerous operation.
Please make sure you check carefully the list of packages to be removed.</source>
        <translation>Operação potencialmente perigosa.
Verificar cuidadosamente a lista de pacotes a serem removidos.</translation>
    </message>
</context>
<context>
    <name>ManageRemotes</name>
    <message>
        <location filename="../remotes.cpp" line="16"/>
        <source>Manage Flatpak Remotes</source>
        <translation>Gerir repositórios remotos flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="23"/>
        <source>For all users</source>
        <translation>Para todos os utilizadores</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="24"/>
        <source>For current user</source>
        <translation>Para o presente utilizador</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="35"/>
        <source>enter Flatpak remote URL</source>
        <translation>introduzir a URL do repositório remoto flatpak</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="38"/>
        <source>enter Flatpakref location to install app</source>
        <translation>para instalar uma aplicação, introduzir a localização do respectivo ficheiro .flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="40"/>
        <source>Add or remove flatpak remotes (repos), or install apps using flatpakref URL or path</source>
        <translation>Adicionar ou remover repositórios remotos flatpak ou instalar aplicações usando a URL ou o caminho para o respectivo ficheiro .flatpakref</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="49"/>
        <source>Remove remote</source>
        <translation>Remover repositório remoto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="54"/>
        <source>Add remote</source>
        <translation>Adicionar repositório remoto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="59"/>
        <source>Install app</source>
        <translation>Instalar aplicação</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="64"/>
        <source>Close</source>
        <translation>Fechar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="81"/>
        <source>Not removable</source>
        <translation>Não removível</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="82"/>
        <source>Flathub is the main Flatpak remote and won&apos;t be removed</source>
        <translation>O Flathub é o principal repositório remoto flatpak e não será removido</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="101"/>
        <source>Error adding remote</source>
        <translation>Erro ao adicionar o repositório remoto</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="102"/>
        <source>Could not add remote - command returned an error. Please double-check the remote address and try again</source>
        <translation>Não foi possível adicionar o repositório remoto - o comando resultou num erro. Verificar o endereço do repositório remoto e voltar a tentar</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Success</source>
        <translation>Êxito</translation>
    </message>
    <message>
        <location filename="../remotes.cpp" line="107"/>
        <source>Remote added successfully</source>
        <translation>Repositório remoto adicionado com êxito</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="71"/>
        <source>License</source>
        <translation>Licença</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="72"/>
        <location filename="../about.cpp" line="82"/>
        <source>Changelog</source>
        <translation>Registo de alterações</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="95"/>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="50"/>
        <source>Warning</source>
        <translation>Aviso</translation>
    </message>
    <message>
        <location filename="../lockfile.cpp" line="51"/>
        <source>Dpkg/apt database is locked by another program: %1
Close the program, or wait until it is done processing and try again.</source>
        <translation>A base de dados do Dpkg/apt está bloqueada por outro programa: %1
Fechar esse programa ou esperar que ele termine e tentar novamente.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="80"/>
        <source>MX Package Installer is a tool used for managing packages on MX Linux
    - installs popular programs from different sources
    - installs programs from the MX Test repo
    - installs programs from Debian Backports repo
    - installs flatpaks</source>
        <translation>O MX-Instalador de Pacotes é usado para gestão dos pacotes de software do MX Linux
    - instala pacotes seleccionados de diferentes origens
    - instala pacotes do repositório de testes do MX (MX Test Repo)
    - instala pacotes do repositório Debian Retroportados (Debian Backports)
    - instala pacotes flatpak</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="88"/>
        <source>Skip online check if it falsely reports lack of internet access.</source>
        <translation>Ignorar verificação de estado on-line se for erradamente indicada falta de acesso à Internet.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="98"/>
        <location filename="../main.cpp" line="106"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="99"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>O utilizador parece ser o root; para usar este programa, sair e voltar a entrar como utilizador normal.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="107"/>
        <source>You must run this program with admin access.</source>
        <translation>Este programa tem de ser executado como administrador.</translation>
    </message>
</context>
</TS>